# frozen_string_literal: true

require 'tilt'

module Lipstick
  module Images
    class Processor < ::Tilt::Template
      class DSL
        def initialize(context)
          @context = context
        end

        # rubocop:disable Security/Eval
        def run(data)
          binding.eval(data)
        end
        # rubocop:enable Security/Eval

        def email_banner(title:, environment:, image: 'logo.png', **kwargs)
          @context.depend_on_asset(image)
          asset = @context.environment.find_asset(image)

          EmailBanner.new(
            image: asset,
            title: title,
            environment: environment,
            background_color: kwargs[:background_color] || '#2A3685',
            resize_to: kwargs[:resize_to] || [78, 78]
          ).to_png
        end

        def logo_only_email_banner(environment:, image: 'logo.png', **kwargs)
          @context.depend_on_asset(image)
          asset = @context.environment.find_asset(image)

          LogoOnlyEmailBanner.new(
            image: asset,
            environment: environment,
            background_color: kwargs[:background_color] || '#2A3685'
          ).to_png
        end
      end

      def prepare; end

      def evaluate(context, _locals)
        DSL.new(context).run(data)
      end
    end
  end
end
